@@ -1,21 +1,21 @@
-
 test_that("easyprint", {
+  m <- leaflet() %>%
+    addTiles() %>%
+    addEasyprint(options = easyprintOptions(
+      title = "Print map",
+      position = "bottomleft",
+      exportOnly = TRUE
+    ))
+  expect_is(m, "leaflet")
 
   m <- leaflet() %>%
-    addTiles() %>%
-    addEasyprint(options = easyprintOptions(
-      title = 'Print map',
-      position = 'bottomleft',
-      exportOnly = TRUE))
-  expect_is(m, "leaflet")
-
-  m <- leaflet()  %>%
     addTiles() %>%
     addEasyprint(options = easyprintOptions(
       sizeModes = "A4Landscape",
-      title = 'Print map',
-      position = 'bottomleft',
-      exportOnly = TRUE))
+      title = "Print map",
+      position = "bottomleft",
+      exportOnly = TRUE
+    ))
   expect_is(m, "leaflet")
 
   cl <- c("class1", "class2")
@@ -31,16 +31,18 @@ test_that("easyprint", {
   expect_equal(deps[[length(deps)]]$name, "lfx-easyprint")
 
   m <- m %>% removeEasyprint()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "removeEasyprint")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "removeEasyprint"
+  )
 
   m <- m %>% easyprintMap()
-  expect_equal(m$x$calls[[length(m$x$calls)]]$method,
-               "easyprintMap")
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$method,
+    "easyprintMap"
+  )
 
   expect_error(easyprintOptions(sizeModes = NULL))
   expect_error(easyprintOptions(sizeModes = NA))
   expect_error(easyprintOptions(sizeModes = ""))
-
 })
-
