@@ -15,5 +15,8 @@ test_that("spin", {
   expect_false(m$x$calls[[length(m$x$calls)]]$args[[1]])
 
   m <- m %>% startSpinner(options = list("lines" = 7, "width" = 12))
-  expect_equal(m$x$calls[[length(m$x$calls)]]$args[[2]], list("lines" = 7, "width" = 12))
+  expect_equal(
+    m$x$calls[[length(m$x$calls)]]$args[[2]],
+    list("lines" = 7, "width" = 12)
+  )
 })
